# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_search.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_search.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import tile_pb2 as tile__pb2
try:
  common__models__pb2 = tile__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = tile__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.tile_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x61ta_search.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\ntile.proto\"4\n\x1a\x44\x61taSearchSchemaGetRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"c\n\x1b\x44\x61taSearchSchemaGetResponse\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12,\n\x0bjson_schema\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xfb\x02\n\x11\x44\x61taSearchRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12.\n\rsearch_params\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\x08\x61oi_geom\x18\x03 \x01(\x0cH\x00\x12\x10\n\x06\x61oi_id\x18\x04 \x01(\tH\x00\x12:\n\ntime_range\x18\x05 \x01(\x0b\x32$.oi.papi.DataSearchRequest.TimeRangeH\x01\x12\x10\n\x06toi_id\x18\x06 \x01(\tH\x01\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\x1aj\n\tTimeRange\x12-\n\tstart_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nfinish_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07spatialB\n\n\x08temporal\"\x86\x01\n\x12\x44\x61taSearchResponse\x12/\n\x0egeojson_struct\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x16\n\x0egeojson_string\x18\x03 \x01(\t\"\xa5\x01\n%DataSearchDisplayTilesBatchGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12.\n\rsearch_params\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x16\n\x0e\x64\x61ta_source_id\x18\x04 \x01(\t\"D\n\rTileSetWithId\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x08tile_set\x18\x02 \x01(\x0b\x32\x15.oi.papi.tile.TileSet\"|\n&DataSearchDisplayTilesBatchGetResponse\x12)\n\ttile_sets\x18\x01 \x03(\x0b\x32\x16.oi.papi.TileSetWithId\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x88\x01\n!DataSearchResourceBatchGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x15\n\rallow_missing\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x16\n\x0e\x64\x61ta_source_id\x18\x04 \x01(\t\"~\n\"DataSearchResourceBatchGetResponse\x12/\n\x0egeojson_struct\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\">\n$DataSearchEstimatedSummaryGetRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"L\n\rSummaryByDate\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12,\n\x08unixtime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x85\x01\n%DataSearchEstimatedSummaryGetResponse\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\x04\x12/\n\x0fsummary_by_date\x18\x03 \x03(\x0b\x32\x16.oi.papi.SummaryByDate\"F\n DataSourceGetDownloadLinkRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"^\n!DataSourceGetDownloadLinkResponse\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rdownload_link\x18\x03 \x01(\t2\xf4\x04\n\rDataSearchApi\x12W\n\nget_schema\x12#.oi.papi.DataSearchSchemaGetRequest\x1a$.oi.papi.DataSearchSchemaGetResponse\x12\x41\n\x06search\x12\x1a.oi.papi.DataSearchRequest\x1a\x1b.oi.papi.DataSearchResponse\x12t\n\x11get_display_tiles\x12..oi.papi.DataSearchDisplayTilesBatchGetRequest\x1a/.oi.papi.DataSearchDisplayTilesBatchGetResponse\x12m\n\x12get_resource_batch\x12*.oi.papi.DataSearchResourceBatchGetRequest\x1a+.oi.papi.DataSearchResourceBatchGetResponse\x12v\n\x15get_estimated_summary\x12-.oi.papi.DataSearchEstimatedSummaryGetRequest\x1a..oi.papi.DataSearchEstimatedSummaryGetResponse\x12j\n\x11get_download_link\x12).oi.papi.DataSourceGetDownloadLinkRequest\x1a*.oi.papi.DataSourceGetDownloadLinkResponseP\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATASEARCHSCHEMAGETREQUEST']._serialized_start=126
  _globals['_DATASEARCHSCHEMAGETREQUEST']._serialized_end=178
  _globals['_DATASEARCHSCHEMAGETRESPONSE']._serialized_start=180
  _globals['_DATASEARCHSCHEMAGETRESPONSE']._serialized_end=279
  _globals['_DATASEARCHREQUEST']._serialized_start=282
  _globals['_DATASEARCHREQUEST']._serialized_end=661
  _globals['_DATASEARCHREQUEST_TIMERANGE']._serialized_start=532
  _globals['_DATASEARCHREQUEST_TIMERANGE']._serialized_end=638
  _globals['_DATASEARCHRESPONSE']._serialized_start=664
  _globals['_DATASEARCHRESPONSE']._serialized_end=798
  _globals['_DATASEARCHDISPLAYTILESBATCHGETREQUEST']._serialized_start=801
  _globals['_DATASEARCHDISPLAYTILESBATCHGETREQUEST']._serialized_end=966
  _globals['_TILESETWITHID']._serialized_start=968
  _globals['_TILESETWITHID']._serialized_end=1036
  _globals['_DATASEARCHDISPLAYTILESBATCHGETRESPONSE']._serialized_start=1038
  _globals['_DATASEARCHDISPLAYTILESBATCHGETRESPONSE']._serialized_end=1162
  _globals['_DATASEARCHRESOURCEBATCHGETREQUEST']._serialized_start=1165
  _globals['_DATASEARCHRESOURCEBATCHGETREQUEST']._serialized_end=1301
  _globals['_DATASEARCHRESOURCEBATCHGETRESPONSE']._serialized_start=1303
  _globals['_DATASEARCHRESOURCEBATCHGETRESPONSE']._serialized_end=1429
  _globals['_DATASEARCHESTIMATEDSUMMARYGETREQUEST']._serialized_start=1431
  _globals['_DATASEARCHESTIMATEDSUMMARYGETREQUEST']._serialized_end=1493
  _globals['_SUMMARYBYDATE']._serialized_start=1495
  _globals['_SUMMARYBYDATE']._serialized_end=1571
  _globals['_DATASEARCHESTIMATEDSUMMARYGETRESPONSE']._serialized_start=1574
  _globals['_DATASEARCHESTIMATEDSUMMARYGETRESPONSE']._serialized_end=1707
  _globals['_DATASOURCEGETDOWNLOADLINKREQUEST']._serialized_start=1709
  _globals['_DATASOURCEGETDOWNLOADLINKREQUEST']._serialized_end=1779
  _globals['_DATASOURCEGETDOWNLOADLINKRESPONSE']._serialized_start=1781
  _globals['_DATASOURCEGETDOWNLOADLINKRESPONSE']._serialized_end=1875
  _globals['_DATASEARCHAPI']._serialized_start=1878
  _globals['_DATASEARCHAPI']._serialized_end=2506
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: order.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import order_recommendation_pb2 as order__recommendation__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.order_recommendation_pb2 import *
from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0border.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1aorder_recommendation.proto\x1a\x13\x63ommon_models.proto\"i\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08scene_id\x18\x02 \x01(\t\x12\x13\n\x0btarget_geom\x18\x03 \x01(\x0c\x12.\n\ritem_metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa8\x03\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x1c\n\x05items\x18\x03 \x03(\x0b\x32\r.oi.papi.Item\x12\x19\n\x11product_spec_name\x18\x04 \x01(\t\x12\"\n\x05state\x18\x05 \x01(\x0e\x32\x13.oi.papi.OrderState\x12\x0f\n\x07\x64\x65tails\x18\x06 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\x12)\n\x08metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x63reator\x18\t \x01(\t\x12.\n\ncreated_on\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x61pproved_by\x18\x0c \x01(\t\x12\x18\n\x10\x61pproval_comment\x18\r \x01(\t\x12\x35\n\x0frecommendations\x18\x0e \x03(\x0b\x32\x1c.oi.papi.OrderRecommendation\"\xd4\x01\n\x10OrderListRequest\x12#\n\x06states\x18\x01 \x03(\x0e\x32\x13.oi.papi.OrderState\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x02 \x03(\t\x12\x14\n\x0cprovider_ids\x18\x03 \x03(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x04 \x03(\t\x12!\n\x19\x61lgorithm_computation_ids\x18\x05 \x03(\t\x12\'\n\npagination\x18\x06 \x01(\x0b\x32\x13.oi.papi.Pagination\"q\n\x11OrderListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1e\n\x06orders\x18\x02 \x03(\x0b\x32\x0e.oi.papi.Order\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x1d\n\x0fOrderGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"F\n\x10OrderGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1d\n\x05order\x18\x02 \x01(\x0b\x32\x0e.oi.papi.Order\"2\n\x13OrderApproveRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"+\n\x14OrderApproveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x90\x01\n\x12OrderCreateRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x19\n\x11product_spec_name\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1c\n\x05items\x18\x04 \x03(\x0b\x32\r.oi.papi.Item\"I\n\x13OrderCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1d\n\x05order\x18\x02 \x01(\x0b\x32\x0e.oi.papi.Order\" \n\x12OrderCancelRequest\x12\n\n\x02id\x18\x01 \x01(\t\"*\n\x13OrderCancelResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r*\xac\x01\n\nOrderState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08\x41PPROVED\x10\x02\x12\n\n\x06QUEUED\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0b\n\x07ORDERED\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\r\n\tDELIVERED\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\x14\n\x10PENDING_APPROVAL\x10\t\x12\r\n\tSUBMITTED\x10\n2\xd7\x02\n\x08OrderApi\x12=\n\x04list\x12\x19.oi.papi.OrderListRequest\x1a\x1a.oi.papi.OrderListResponse\x12:\n\x03get\x12\x18.oi.papi.OrderGetRequest\x1a\x19.oi.papi.OrderGetResponse\x12\x43\n\x06\x63reate\x12\x1b.oi.papi.OrderCreateRequest\x1a\x1c.oi.papi.OrderCreateResponse\x12\x46\n\x07\x61pprove\x12\x1c.oi.papi.OrderApproveRequest\x1a\x1d.oi.papi.OrderApproveResponse\x12\x43\n\x06\x63\x61ncel\x12\x1b.oi.papi.OrderCancelRequest\x1a\x1c.oi.papi.OrderCancelResponseP\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERSTATE']._serialized_start=1501
  _globals['_ORDERSTATE']._serialized_end=1673
  _globals['_ITEM']._serialized_start=136
  _globals['_ITEM']._serialized_end=241
  _globals['_ORDER']._serialized_start=244
  _globals['_ORDER']._serialized_end=668
  _globals['_ORDERLISTREQUEST']._serialized_start=671
  _globals['_ORDERLISTREQUEST']._serialized_end=883
  _globals['_ORDERLISTRESPONSE']._serialized_start=885
  _globals['_ORDERLISTRESPONSE']._serialized_end=998
  _globals['_ORDERGETREQUEST']._serialized_start=1000
  _globals['_ORDERGETREQUEST']._serialized_end=1029
  _globals['_ORDERGETRESPONSE']._serialized_start=1031
  _globals['_ORDERGETRESPONSE']._serialized_end=1101
  _globals['_ORDERAPPROVEREQUEST']._serialized_start=1103
  _globals['_ORDERAPPROVEREQUEST']._serialized_end=1153
  _globals['_ORDERAPPROVERESPONSE']._serialized_start=1155
  _globals['_ORDERAPPROVERESPONSE']._serialized_end=1198
  _globals['_ORDERCREATEREQUEST']._serialized_start=1201
  _globals['_ORDERCREATEREQUEST']._serialized_end=1345
  _globals['_ORDERCREATERESPONSE']._serialized_start=1347
  _globals['_ORDERCREATERESPONSE']._serialized_end=1420
  _globals['_ORDERCANCELREQUEST']._serialized_start=1422
  _globals['_ORDERCANCELREQUEST']._serialized_end=1454
  _globals['_ORDERCANCELRESPONSE']._serialized_start=1456
  _globals['_ORDERCANCELRESPONSE']._serialized_end=1498
  _globals['_ORDERAPI']._serialized_start=1676
  _globals['_ORDERAPI']._serialized_end=2019
# @@protoc_insertion_point(module_scope)



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import tile_pb2 as _tile_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from tile_pb2 import Bounds as Bounds
from tile_pb2 import TileMatrix as TileMatrix
from tile_pb2 import TileAccessInfo as TileAccessInfo
from tile_pb2 import TileSet as TileSet
from tile_pb2 import TileSetListRequest as TileSetListRequest
from tile_pb2 import TileSetListResponse as TileSetListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class DataSearchSchemaGetRequest(_message.Message):
    __slots__ = ("data_source_id",)
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    def __init__(self, data_source_id: _Optional[str] = ...) -> None: ...

class DataSearchSchemaGetResponse(_message.Message):
    __slots__ = ("data_source_id", "json_schema")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    json_schema: _struct_pb2.Struct
    def __init__(self, data_source_id: _Optional[str] = ..., json_schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DataSearchRequest(_message.Message):
    __slots__ = ("data_source_id", "search_params", "aoi_geom", "aoi_id", "time_range", "toi_id", "pagination")
    class TimeRange(_message.Message):
        __slots__ = ("start_utc", "finish_utc")
        START_UTC_FIELD_NUMBER: _ClassVar[int]
        FINISH_UTC_FIELD_NUMBER: _ClassVar[int]
        start_utc: _timestamp_pb2.Timestamp
        finish_utc: _timestamp_pb2.Timestamp
        def __init__(self, start_utc: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., finish_utc: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    SEARCH_PARAMS_FIELD_NUMBER: _ClassVar[int]
    AOI_GEOM_FIELD_NUMBER: _ClassVar[int]
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    TIME_RANGE_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    search_params: _struct_pb2.Struct
    aoi_geom: bytes
    aoi_id: str
    time_range: DataSearchRequest.TimeRange
    toi_id: str
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, data_source_id: _Optional[str] = ..., search_params: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., aoi_geom: _Optional[bytes] = ..., aoi_id: _Optional[str] = ..., time_range: _Optional[_Union[DataSearchRequest.TimeRange, _Mapping]] = ..., toi_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class DataSearchResponse(_message.Message):
    __slots__ = ("geojson_struct", "pagination", "geojson_string")
    GEOJSON_STRUCT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    GEOJSON_STRING_FIELD_NUMBER: _ClassVar[int]
    geojson_struct: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    pagination: _common_models_pb2_1.Pagination
    geojson_string: str
    def __init__(self, geojson_struct: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., geojson_string: _Optional[str] = ...) -> None: ...

class DataSearchDisplayTilesBatchGetRequest(_message.Message):
    __slots__ = ("ids", "search_params", "pagination", "data_source_id")
    IDS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    search_params: _struct_pb2.Struct
    pagination: _common_models_pb2_1.Pagination
    data_source_id: str
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., search_params: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., data_source_id: _Optional[str] = ...) -> None: ...

class TileSetWithId(_message.Message):
    __slots__ = ("id", "tile_set")
    ID_FIELD_NUMBER: _ClassVar[int]
    TILE_SET_FIELD_NUMBER: _ClassVar[int]
    id: str
    tile_set: _tile_pb2.TileSet
    def __init__(self, id: _Optional[str] = ..., tile_set: _Optional[_Union[_tile_pb2.TileSet, _Mapping]] = ...) -> None: ...

class DataSearchDisplayTilesBatchGetResponse(_message.Message):
    __slots__ = ("tile_sets", "pagination")
    TILE_SETS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    tile_sets: _containers.RepeatedCompositeFieldContainer[TileSetWithId]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, tile_sets: _Optional[_Iterable[_Union[TileSetWithId, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class DataSearchResourceBatchGetRequest(_message.Message):
    __slots__ = ("ids", "allow_missing", "pagination", "data_source_id")
    IDS_FIELD_NUMBER: _ClassVar[int]
    ALLOW_MISSING_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    allow_missing: bool
    pagination: _common_models_pb2_1.Pagination
    data_source_id: str
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., allow_missing: bool = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., data_source_id: _Optional[str] = ...) -> None: ...

class DataSearchResourceBatchGetResponse(_message.Message):
    __slots__ = ("geojson_struct", "pagination")
    GEOJSON_STRUCT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    geojson_struct: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, geojson_struct: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class DataSearchEstimatedSummaryGetRequest(_message.Message):
    __slots__ = ("data_source_id",)
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    def __init__(self, data_source_id: _Optional[str] = ...) -> None: ...

class SummaryByDate(_message.Message):
    __slots__ = ("count", "unixtime")
    COUNT_FIELD_NUMBER: _ClassVar[int]
    UNIXTIME_FIELD_NUMBER: _ClassVar[int]
    count: int
    unixtime: _timestamp_pb2.Timestamp
    def __init__(self, count: _Optional[int] = ..., unixtime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DataSearchEstimatedSummaryGetResponse(_message.Message):
    __slots__ = ("data_source_id", "total_count", "summary_by_date")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_BY_DATE_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    total_count: int
    summary_by_date: _containers.RepeatedCompositeFieldContainer[SummaryByDate]
    def __init__(self, data_source_id: _Optional[str] = ..., total_count: _Optional[int] = ..., summary_by_date: _Optional[_Iterable[_Union[SummaryByDate, _Mapping]]] = ...) -> None: ...

class DataSourceGetDownloadLinkRequest(_message.Message):
    __slots__ = ("data_source_id", "id")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    id: str
    def __init__(self, data_source_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class DataSourceGetDownloadLinkResponse(_message.Message):
    __slots__ = ("data_source_id", "id", "download_link")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_LINK_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    id: str
    download_link: str
    def __init__(self, data_source_id: _Optional[str] = ..., id: _Optional[str] = ..., download_link: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AOIExportFileType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_EXPORT_FILETYPE: _ClassVar[AOIExportFileType]
    GEOJSON: _ClassVar[AOIExportFileType]
    ESRI_SHAPEFILE: _ClassVar[AOIExportFileType]
    GEOPACKAGE: _ClassVar[AOIExportFileType]

class AOIExportArchiveType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_ARCHIVE_TYPE: _ClassVar[AOIExportArchiveType]
    ZIP_FILE: _ClassVar[AOIExportArchiveType]
UNKNOWN_EXPORT_FILETYPE: AOIExportFileType
GEOJSON: AOIExportFileType
ESRI_SHAPEFILE: AOIExportFileType
GEOPACKAGE: AOIExportFileType
UNKNOWN_ARCHIVE_TYPE: AOIExportArchiveType
ZIP_FILE: AOIExportArchiveType

class AOIExportRequest(_message.Message):
    __slots__ = ("aoi_ids", "file_type", "archive_type", "file_name")
    AOI_IDS_FIELD_NUMBER: _ClassVar[int]
    FILE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ARCHIVE_TYPE_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    aoi_ids: _containers.RepeatedScalarFieldContainer[str]
    file_type: AOIExportFileType
    archive_type: AOIExportArchiveType
    file_name: str
    def __init__(self, aoi_ids: _Optional[_Iterable[str]] = ..., file_type: _Optional[_Union[AOIExportFileType, str]] = ..., archive_type: _Optional[_Union[AOIExportArchiveType, str]] = ..., file_name: _Optional[str] = ...) -> None: ...

class AOICollectionExportRequest(_message.Message):
    __slots__ = ("aoi_collection_id", "file_type", "archive_type", "file_name")
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    FILE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ARCHIVE_TYPE_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    aoi_collection_id: str
    file_type: AOIExportFileType
    archive_type: AOIExportArchiveType
    file_name: str
    def __init__(self, aoi_collection_id: _Optional[str] = ..., file_type: _Optional[_Union[AOIExportFileType, str]] = ..., archive_type: _Optional[_Union[AOIExportArchiveType, str]] = ..., file_name: _Optional[str] = ...) -> None: ...

class AOIExportResponse(_message.Message):
    __slots__ = ("location",)
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    location: str
    def __init__(self, location: _Optional[str] = ...) -> None: ...

class AOICollectionExportResponse(_message.Message):
    __slots__ = ("location",)
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    location: str
    def __init__(self, location: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import analysis_config_pb2 as _analysis_config_pb2
import common_models_pb2 as _common_models_pb2_1
import analysis_pb2 as _analysis_pb2
import analysis_version_pb2 as _analysis_version_pb2
import algorithm_config_pb2 as _algorithm_config_pb2
import analysis_computation_pb2 as _analysis_computation_pb2
import common_models_pb2 as _common_models_pb2_1_1
import analysis_pb2 as _analysis_pb2_1
import aoi_collection_pb2 as _aoi_collection_pb2
import common_models_pb2 as _common_models_pb2_1_1_1
import result_pb2 as _result_pb2
import common_models_pb2 as _common_models_pb2_1_1_1_1
import toi_pb2 as _toi_pb2
import project_filter_pb2 as _project_filter_pb2
import common_models_pb2 as _common_models_pb2_1_1_1_1_1
import filter_pb2 as _filter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from analysis_config_pb2 import AnalysisConfig as AnalysisConfig
from analysis_config_pb2 import AnalysisConfigCreateRequest as AnalysisConfigCreateRequest
from analysis_config_pb2 import AnalysisConfigCreateResponse as AnalysisConfigCreateResponse
from analysis_config_pb2 import AnalysisConfigUpdateRequest as AnalysisConfigUpdateRequest
from analysis_config_pb2 import AnalysisConfigUpdateResponse as AnalysisConfigUpdateResponse
from analysis_config_pb2 import AnalysisConfigGetRequest as AnalysisConfigGetRequest
from analysis_config_pb2 import AnalysisConfigGetResponse as AnalysisConfigGetResponse
from analysis_config_pb2 import AnalysisConfigListRequest as AnalysisConfigListRequest
from analysis_config_pb2 import AnalysisConfigListResponse as AnalysisConfigListResponse
from analysis_config_pb2 import AnalysisConfigDeactivateRequest as AnalysisConfigDeactivateRequest
from analysis_config_pb2 import AnalysisConfigDeactivateResponse as AnalysisConfigDeactivateResponse
from analysis_computation_pb2 import AnalysisComputationCreateRequest as AnalysisComputationCreateRequest
from analysis_computation_pb2 import AnalysisComputationCreateResponse as AnalysisComputationCreateResponse
from analysis_computation_pb2 import AnalysisComputationRunRequest as AnalysisComputationRunRequest
from analysis_computation_pb2 import AnalysisComputationRunResponse as AnalysisComputationRunResponse
from analysis_computation_pb2 import AnalysisComputationGetRequest as AnalysisComputationGetRequest
from analysis_computation_pb2 import AnalysisComputationNode as AnalysisComputationNode
from analysis_computation_pb2 import AnalysisComputation as AnalysisComputation
from analysis_computation_pb2 import AnalysisComputationGetResponse as AnalysisComputationGetResponse
from analysis_computation_pb2 import AnalysisComputationListRequest as AnalysisComputationListRequest
from analysis_computation_pb2 import AnalysisComputationListResponse as AnalysisComputationListResponse
from aoi_collection_pb2 import AOICollection as AOICollection
from aoi_collection_pb2 import AOIInfo as AOIInfo
from aoi_collection_pb2 import AOICollectionCreateRequest as AOICollectionCreateRequest
from aoi_collection_pb2 import AOICollectionCreateResponse as AOICollectionCreateResponse
from aoi_collection_pb2 import AOICollectionGetRequest as AOICollectionGetRequest
from aoi_collection_pb2 import AOICollectionGetResponse as AOICollectionGetResponse
from aoi_collection_pb2 import AOICollectionAddRequest as AOICollectionAddRequest
from aoi_collection_pb2 import AOICollectionAddResponse as AOICollectionAddResponse
from aoi_collection_pb2 import AOICollectionRemoveRequest as AOICollectionRemoveRequest
from aoi_collection_pb2 import AOICollectionRemoveResponse as AOICollectionRemoveResponse
from aoi_collection_pb2 import AOICollectionCloneRequest as AOICollectionCloneRequest
from aoi_collection_pb2 import AOICollectionCloneResponse as AOICollectionCloneResponse
from aoi_collection_pb2 import AOICollectionListRequest as AOICollectionListRequest
from aoi_collection_pb2 import AOICollectionListResponse as AOICollectionListResponse
from result_pb2 import ExportFile as ExportFile
from result_pb2 import ExportCredentials as ExportCredentials
from result_pb2 import Result as Result
from result_pb2 import ResultGetRequest as ResultGetRequest
from result_pb2 import ResultGetResponse as ResultGetResponse
from project_filter_pb2 import ProjectFilter as ProjectFilter
from project_filter_pb2 import ProjectFilterMappingCreateRequest as ProjectFilterMappingCreateRequest
from project_filter_pb2 import ProjectFilterMappingCreateResponse as ProjectFilterMappingCreateResponse
from project_filter_pb2 import ProjectFilterMappingDeleteRequest as ProjectFilterMappingDeleteRequest
from project_filter_pb2 import ProjectFilterMappingDeleteResponse as ProjectFilterMappingDeleteResponse

DESCRIPTOR: _descriptor.FileDescriptor

class Project(_message.Message):
    __slots__ = ("id", "name", "description", "creator", "status", "aoi_collections", "analysis_computations", "analysis_configs", "start_date", "end_date", "created_ts", "available_filters", "applied_filters", "time_ranges", "type")
    class ProjectStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_PROJECT_STATUS: _ClassVar[Project.ProjectStatus]
        COMPLETED: _ClassVar[Project.ProjectStatus]
        RUNNING: _ClassVar[Project.ProjectStatus]
        STOPPED: _ClassVar[Project.ProjectStatus]
        NOT_STARTED: _ClassVar[Project.ProjectStatus]
        FAILED: _ClassVar[Project.ProjectStatus]
    UNKNOWN_PROJECT_STATUS: Project.ProjectStatus
    COMPLETED: Project.ProjectStatus
    RUNNING: Project.ProjectStatus
    STOPPED: Project.ProjectStatus
    NOT_STARTED: Project.ProjectStatus
    FAILED: Project.ProjectStatus
    class TimeRange(_message.Message):
        __slots__ = ("start", "end")
        START_FIELD_NUMBER: _ClassVar[int]
        END_FIELD_NUMBER: _ClassVar[int]
        start: _timestamp_pb2.Timestamp
        end: _timestamp_pb2.Timestamp
        def __init__(self, start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATIONS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    START_DATE_FIELD_NUMBER: _ClassVar[int]
    END_DATE_FIELD_NUMBER: _ClassVar[int]
    CREATED_TS_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_FILTERS_FIELD_NUMBER: _ClassVar[int]
    APPLIED_FILTERS_FIELD_NUMBER: _ClassVar[int]
    TIME_RANGES_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    creator: str
    status: Project.ProjectStatus
    aoi_collections: _containers.RepeatedCompositeFieldContainer[_aoi_collection_pb2.AOICollection]
    analysis_computations: _containers.RepeatedCompositeFieldContainer[_analysis_computation_pb2.AnalysisComputation]
    analysis_configs: _containers.RepeatedCompositeFieldContainer[_analysis_config_pb2.AnalysisConfig]
    start_date: _timestamp_pb2.Timestamp
    end_date: _timestamp_pb2.Timestamp
    created_ts: _timestamp_pb2.Timestamp
    available_filters: _containers.RepeatedCompositeFieldContainer[_project_filter_pb2.ProjectFilter]
    applied_filters: _containers.RepeatedCompositeFieldContainer[_project_filter_pb2.ProjectFilter]
    time_ranges: _containers.RepeatedCompositeFieldContainer[Project.TimeRange]
    type: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., creator: _Optional[str] = ..., status: _Optional[_Union[Project.ProjectStatus, str]] = ..., aoi_collections: _Optional[_Iterable[_Union[_aoi_collection_pb2.AOICollection, _Mapping]]] = ..., analysis_computations: _Optional[_Iterable[_Union[_analysis_computation_pb2.AnalysisComputation, _Mapping]]] = ..., analysis_configs: _Optional[_Iterable[_Union[_analysis_config_pb2.AnalysisConfig, _Mapping]]] = ..., start_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., available_filters: _Optional[_Iterable[_Union[_project_filter_pb2.ProjectFilter, _Mapping]]] = ..., applied_filters: _Optional[_Iterable[_Union[_project_filter_pb2.ProjectFilter, _Mapping]]] = ..., time_ranges: _Optional[_Iterable[_Union[Project.TimeRange, _Mapping]]] = ..., type: _Optional[str] = ...) -> None: ...

class ProjectListRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2_1_1_1_1_1.Pagination
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2_1_1_1_1_1.Pagination, _Mapping]] = ...) -> None: ...

class ProjectListResponse(_message.Message):
    __slots__ = ("status_code", "projects", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    projects: _containers.RepeatedCompositeFieldContainer[Project]
    pagination: _common_models_pb2_1_1_1_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., projects: _Optional[_Iterable[_Union[Project, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1_1_1_1.Pagination, _Mapping]] = ...) -> None: ...

class ProjectGetRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ProjectGetResponse(_message.Message):
    __slots__ = ("status_code", "project")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project: Project
    def __init__(self, status_code: _Optional[int] = ..., project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class ProjectCreateRequest(_message.Message):
    __slots__ = ("name", "description")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class ProjectCreateResponse(_message.Message):
    __slots__ = ("status_code", "project")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project: Project
    def __init__(self, status_code: _Optional[int] = ..., project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class ProjectUpdateRequest(_message.Message):
    __slots__ = ("projects",)
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[Project]
    def __init__(self, projects: _Optional[_Iterable[_Union[Project, _Mapping]]] = ...) -> None: ...

class ProjectUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectDeleteRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectRunRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectRunResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectCloneRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ProjectCloneResponse(_message.Message):
    __slots__ = ("status_code", "project")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project: Project
    def __init__(self, status_code: _Optional[int] = ..., project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class ProjectCreditEstimateRequest(_message.Message):
    __slots__ = ("project_id",)
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class ProjectCreditEstimateResponse(_message.Message):
    __slots__ = ("status_code", "applied_credits", "new_credits", "message", "is_runnable")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    APPLIED_CREDITS_FIELD_NUMBER: _ClassVar[int]
    NEW_CREDITS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    IS_RUNNABLE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    applied_credits: float
    new_credits: float
    message: str
    is_runnable: bool
    def __init__(self, status_code: _Optional[int] = ..., applied_credits: _Optional[float] = ..., new_credits: _Optional[float] = ..., message: _Optional[str] = ..., is_runnable: bool = ...) -> None: ...

class ProjectRequestAccessRequest(_message.Message):
    __slots__ = ("project_id",)
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class ProjectRequestAccessResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AnalysisAlgorithmNode(_message.Message):
    __slots__ = ("name", "algorithm_version_id", "children")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    name: str
    algorithm_version_id: str
    children: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., algorithm_version_id: _Optional[str] = ..., children: _Optional[_Iterable[str]] = ...) -> None: ...

class AnalysisCreateRequest(_message.Message):
    __slots__ = ("name", "author")
    NAME_FIELD_NUMBER: _ClassVar[int]
    AUTHOR_FIELD_NUMBER: _ClassVar[int]
    name: str
    author: str
    def __init__(self, name: _Optional[str] = ..., author: _Optional[str] = ...) -> None: ...

class AnalysisCreateResponse(_message.Message):
    __slots__ = ("status_code", "analysis")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis: Analysis
    def __init__(self, status_code: _Optional[int] = ..., analysis: _Optional[_Union[Analysis, _Mapping]] = ...) -> None: ...

class AnalysisAlgorithmConfigNode(_message.Message):
    __slots__ = ("name", "algorithm_config_id")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    algorithm_config_id: str
    def __init__(self, name: _Optional[str] = ..., algorithm_config_id: _Optional[str] = ...) -> None: ...

class AnalysisGetRequest(_message.Message):
    __slots__ = ("ids", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class Analysis(_message.Message):
    __slots__ = ("id", "author", "created_on", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    AUTHOR_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    author: str
    created_on: _timestamp_pb2.Timestamp
    name: str
    def __init__(self, id: _Optional[str] = ..., author: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., name: _Optional[str] = ...) -> None: ...

class AnalysisGetResponse(_message.Message):
    __slots__ = ("status_code", "analyses", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analyses: _containers.RepeatedCompositeFieldContainer[Analysis]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analyses: _Optional[_Iterable[_Union[Analysis, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisListRequest(_message.Message):
    __slots__ = ("search_text", "min_created_on", "max_created_on", "pagination")
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    search_text: str
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    pagination: _common_models_pb2.Pagination
    def __init__(self, search_text: _Optional[str] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisListResponse(_message.Message):
    __slots__ = ("status_code", "analyses", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analyses: _containers.RepeatedCompositeFieldContainer[Analysis]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analyses: _Optional[_Iterable[_Union[Analysis, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...



# Copyright 2017-2021 Orbital Insight Inc., all rights reserved.
# Contains confidential and trade secret information.
# Government Users:  Commercial Computer Software - Use governed by
# terms of Orbital Insight commercial license agreement.


# TODO:
# add retry
# handle exceptions
# add custom logic (request_id, ....)

import grpc
from terrascope_api.terrascope_base_api import TerrascopeBaseApi
from terrascope_api import models


class TerrascopeSyncClient:
    def __init__(self, oi_papi_url, port=443, secure=True, api_token=None):
        self.api = TerrascopeSyncApi(oi_papi_url, port, secure, api_token=api_token)
        self.models = models


class TerrascopeSyncApi(TerrascopeBaseApi):

    def _get_channel(self, channel_credentials: grpc.ChannelCredentials):
        token_creds = grpc.access_token_call_credentials(self.api_token)
        creds = grpc.composite_channel_credentials(channel_credentials, token_creds)
        return grpc.secure_channel(f"{self._oi_papi_url}:{self._port}",
                                   creds,
                                   options=self.options,
                                   compression=None)

    def __del__(self):
        self._channel.close()



from google.protobuf import struct_pb2 as _struct_pb2
import common_models_pb2 as _common_models_pb2
import aoi_collection_pb2 as _aoi_collection_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from aoi_collection_pb2 import AOICollection as AOICollection
from aoi_collection_pb2 import AOIInfo as AOIInfo
from aoi_collection_pb2 import AOICollectionCreateRequest as AOICollectionCreateRequest
from aoi_collection_pb2 import AOICollectionCreateResponse as AOICollectionCreateResponse
from aoi_collection_pb2 import AOICollectionGetRequest as AOICollectionGetRequest
from aoi_collection_pb2 import AOICollectionGetResponse as AOICollectionGetResponse
from aoi_collection_pb2 import AOICollectionAddRequest as AOICollectionAddRequest
from aoi_collection_pb2 import AOICollectionAddResponse as AOICollectionAddResponse
from aoi_collection_pb2 import AOICollectionRemoveRequest as AOICollectionRemoveRequest
from aoi_collection_pb2 import AOICollectionRemoveResponse as AOICollectionRemoveResponse
from aoi_collection_pb2 import AOICollectionCloneRequest as AOICollectionCloneRequest
from aoi_collection_pb2 import AOICollectionCloneResponse as AOICollectionCloneResponse
from aoi_collection_pb2 import AOICollectionListRequest as AOICollectionListRequest
from aoi_collection_pb2 import AOICollectionListResponse as AOICollectionListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class LibraryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PRIVATE: _ClassVar[LibraryType]
    PUBLIC: _ClassVar[LibraryType]
PRIVATE: LibraryType
PUBLIC: LibraryType

class AOIStats(_message.Message):
    __slots__ = ("categories", "countries", "sources", "states", "tags", "types")
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    COUNTRIES_FIELD_NUMBER: _ClassVar[int]
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    STATES_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    categories: _struct_pb2.Struct
    countries: _struct_pb2.Struct
    sources: _struct_pb2.Struct
    states: _struct_pb2.Struct
    tags: _struct_pb2.Struct
    types: _struct_pb2.Struct
    def __init__(self, categories: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., countries: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., sources: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., states: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., tags: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., types: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class AOIStatsGetRequest(_message.Message):
    __slots__ = ("bbox", "category", "type", "tags", "search_text", "country", "state", "min_area", "max_area", "sources", "library_type")
    BBOX_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    MIN_AREA_FIELD_NUMBER: _ClassVar[int]
    MAX_AREA_FIELD_NUMBER: _ClassVar[int]
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_TYPE_FIELD_NUMBER: _ClassVar[int]
    bbox: _containers.RepeatedScalarFieldContainer[float]
    category: str
    type: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    search_text: str
    country: str
    state: str
    min_area: float
    max_area: float
    sources: _containers.RepeatedScalarFieldContainer[str]
    library_type: LibraryType
    def __init__(self, bbox: _Optional[_Iterable[float]] = ..., category: _Optional[str] = ..., type: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., search_text: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., min_area: _Optional[float] = ..., max_area: _Optional[float] = ..., sources: _Optional[_Iterable[str]] = ..., library_type: _Optional[_Union[LibraryType, str]] = ...) -> None: ...

class AOIStatsGetResponse(_message.Message):
    __slots__ = ("status_code", "aoi_stats")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_STATS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_stats: AOIStats
    def __init__(self, status_code: _Optional[int] = ..., aoi_stats: _Optional[_Union[AOIStats, _Mapping]] = ...) -> None: ...

class AOICluster(_message.Message):
    __slots__ = ("lat", "long", "count")
    LAT_FIELD_NUMBER: _ClassVar[int]
    LONG_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    lat: float
    long: float
    count: int
    def __init__(self, lat: _Optional[float] = ..., long: _Optional[float] = ..., count: _Optional[int] = ...) -> None: ...

class AOIClusterGetRequest(_message.Message):
    __slots__ = ("bbox", "category", "type", "tags", "search_text", "country", "state", "min_area", "max_area", "sources", "library_type")
    BBOX_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    MIN_AREA_FIELD_NUMBER: _ClassVar[int]
    MAX_AREA_FIELD_NUMBER: _ClassVar[int]
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_TYPE_FIELD_NUMBER: _ClassVar[int]
    bbox: _containers.RepeatedScalarFieldContainer[float]
    category: str
    type: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    search_text: str
    country: str
    state: str
    min_area: float
    max_area: float
    sources: _containers.RepeatedScalarFieldContainer[str]
    library_type: LibraryType
    def __init__(self, bbox: _Optional[_Iterable[float]] = ..., category: _Optional[str] = ..., type: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., search_text: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., min_area: _Optional[float] = ..., max_area: _Optional[float] = ..., sources: _Optional[_Iterable[str]] = ..., library_type: _Optional[_Union[LibraryType, str]] = ...) -> None: ...

class AOIClusterGetResponse(_message.Message):
    __slots__ = ("status_code", "aoi_clusters")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_CLUSTERS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_clusters: _containers.RepeatedCompositeFieldContainer[AOICluster]
    def __init__(self, status_code: _Optional[int] = ..., aoi_clusters: _Optional[_Iterable[_Union[AOICluster, _Mapping]]] = ...) -> None: ...

class AOICatalogAddRequest(_message.Message):
    __slots__ = ("aoi_ids",)
    AOI_IDS_FIELD_NUMBER: _ClassVar[int]
    aoi_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, aoi_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AOICatalogAddResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AOICatalogDeleteRequest(_message.Message):
    __slots__ = ("aoi_ids",)
    AOI_IDS_FIELD_NUMBER: _ClassVar[int]
    aoi_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, aoi_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AOICatalogDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AOICatalogGetPrivateCatalogRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AOICatalogGetPrivateCatalogResponse(_message.Message):
    __slots__ = ("user_collection",)
    USER_COLLECTION_FIELD_NUMBER: _ClassVar[int]
    user_collection: _aoi_collection_pb2.AOICollection
    def __init__(self, user_collection: _Optional[_Union[_aoi_collection_pb2.AOICollection, _Mapping]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class FilterCreateRequest(_message.Message):
    __slots__ = ("data_type", "expression", "description", "name")
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    data_type: str
    expression: str
    description: str
    name: str
    def __init__(self, data_type: _Optional[str] = ..., expression: _Optional[str] = ..., description: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class FilterCreateResponse(_message.Message):
    __slots__ = ("status_code", "filter_id")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    FILTER_ID_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    filter_id: str
    def __init__(self, status_code: _Optional[int] = ..., filter_id: _Optional[str] = ...) -> None: ...

class FilterDeleteRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class FilterDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class FilterMappingCreateRequest(_message.Message):
    __slots__ = ("computation_id", "filter_id")
    COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    FILTER_ID_FIELD_NUMBER: _ClassVar[int]
    computation_id: str
    filter_id: str
    def __init__(self, computation_id: _Optional[str] = ..., filter_id: _Optional[str] = ...) -> None: ...

class FilterMappingCreateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class FilterListRequest(_message.Message):
    __slots__ = ("pagination", "data_types")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    data_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., data_types: _Optional[_Iterable[str]] = ...) -> None: ...

class Filter(_message.Message):
    __slots__ = ("id", "name", "description", "expression", "data_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    expression: str
    data_type: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., expression: _Optional[str] = ..., data_type: _Optional[str] = ...) -> None: ...

class FilterListResponse(_message.Message):
    __slots__ = ("status_code", "filters", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    filters: _containers.RepeatedCompositeFieldContainer[Filter]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., filters: _Optional[_Iterable[_Union[Filter, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: filter.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66ilter.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"_\n\x13\x46ilterCreateRequest\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\">\n\x14\x46ilterCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tfilter_id\x18\x02 \x01(\t\"\"\n\x13\x46ilterDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"+\n\x14\x46ilterDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"G\n\x1a\x46ilterMappingCreateRequest\x12\x16\n\x0e\x63omputation_id\x18\x01 \x01(\t\x12\x11\n\tfilter_id\x18\x02 \x01(\t\"2\n\x1b\x46ilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"P\n\x11\x46ilterListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x12\n\ndata_types\x18\x02 \x03(\t\"^\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\"t\n\x12\x46ilterListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12 \n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x0f.oi.papi.Filter\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\xb7\x02\n\tFilterApi\x12\x45\n\x06\x63reate\x12\x1c.oi.papi.FilterCreateRequest\x1a\x1d.oi.papi.FilterCreateResponse\x12\x45\n\x06\x64\x65lete\x12\x1c.oi.papi.FilterDeleteRequest\x1a\x1d.oi.papi.FilterDeleteResponse\x12[\n\x0e\x63reate_mapping\x12#.oi.papi.FilterMappingCreateRequest\x1a$.oi.papi.FilterMappingCreateResponse\x12?\n\x04list\x12\x1a.oi.papi.FilterListRequest\x1a\x1b.oi.papi.FilterListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FILTERCREATEREQUEST']._serialized_start=46
  _globals['_FILTERCREATEREQUEST']._serialized_end=141
  _globals['_FILTERCREATERESPONSE']._serialized_start=143
  _globals['_FILTERCREATERESPONSE']._serialized_end=205
  _globals['_FILTERDELETEREQUEST']._serialized_start=207
  _globals['_FILTERDELETEREQUEST']._serialized_end=241
  _globals['_FILTERDELETERESPONSE']._serialized_start=243
  _globals['_FILTERDELETERESPONSE']._serialized_end=286
  _globals['_FILTERMAPPINGCREATEREQUEST']._serialized_start=288
  _globals['_FILTERMAPPINGCREATEREQUEST']._serialized_end=359
  _globals['_FILTERMAPPINGCREATERESPONSE']._serialized_start=361
  _globals['_FILTERMAPPINGCREATERESPONSE']._serialized_end=411
  _globals['_FILTERLISTREQUEST']._serialized_start=413
  _globals['_FILTERLISTREQUEST']._serialized_end=493
  _globals['_FILTER']._serialized_start=495
  _globals['_FILTER']._serialized_end=589
  _globals['_FILTERLISTRESPONSE']._serialized_start=591
  _globals['_FILTERLISTRESPONSE']._serialized_end=707
  _globals['_FILTERAPI']._serialized_start=710
  _globals['_FILTERAPI']._serialized_end=1021
# @@protoc_insertion_point(module_scope)



import common_models_pb2 as _common_models_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class TokenCreateRequest(_message.Message):
    __slots__ = ("duration_minutes", "for_user_id")
    DURATION_MINUTES_FIELD_NUMBER: _ClassVar[int]
    FOR_USER_ID_FIELD_NUMBER: _ClassVar[int]
    duration_minutes: int
    for_user_id: str
    def __init__(self, duration_minutes: _Optional[int] = ..., for_user_id: _Optional[str] = ...) -> None: ...

class TokenCreateResponse(_message.Message):
    __slots__ = ("status_code", "jwt_token")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    JWT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    jwt_token: str
    def __init__(self, status_code: _Optional[int] = ..., jwt_token: _Optional[str] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AlgorithmManifestSchemaGetRequest(_message.Message):
    __slots__ = ("version",)
    VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    def __init__(self, version: _Optional[str] = ...) -> None: ...

class AlgorithmManifestSchemaGetResponse(_message.Message):
    __slots__ = ("status_code", "version", "schema")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    version: str
    schema: _struct_pb2.Struct
    def __init__(self, status_code: _Optional[int] = ..., version: _Optional[str] = ..., schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analysis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'analysis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61nalysis.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"U\n\x15\x41nalysisAlgorithmNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1c\n\x14\x61lgorithm_version_id\x18\x02 \x01(\t\x12\x10\n\x08\x63hildren\x18\x03 \x03(\t\"5\n\x15\x41nalysisCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\"R\n\x16\x41nalysisCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12#\n\x08\x61nalysis\x18\x02 \x01(\x0b\x32\x11.oi.papi.Analysis\"H\n\x1b\x41nalysisAlgorithmConfigNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13\x61lgorithm_config_id\x18\x02 \x01(\t\"J\n\x12\x41nalysisGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"d\n\x08\x41nalysis\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\"x\n\x13\x41nalysisGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12#\n\x08\x61nalyses\x18\x02 \x03(\x0b\x32\x11.oi.papi.Analysis\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xbb\x01\n\x13\x41nalysisListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x32\n\x0emin_created_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\npagination\x18\x04 \x01(\x0b\x32\x13.oi.papi.Pagination\"y\n\x14\x41nalysisListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12#\n\x08\x61nalyses\x18\x02 \x03(\x0b\x32\x11.oi.papi.Analysis\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\xdf\x01\n\x0b\x41nalysisApi\x12I\n\x06\x63reate\x12\x1e.oi.papi.AnalysisCreateRequest\x1a\x1f.oi.papi.AnalysisCreateResponse\x12@\n\x03get\x12\x1b.oi.papi.AnalysisGetRequest\x1a\x1c.oi.papi.AnalysisGetResponse\x12\x43\n\x04list\x12\x1c.oi.papi.AnalysisListRequest\x1a\x1d.oi.papi.AnalysisListResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYSISALGORITHMNODE']._serialized_start=81
  _globals['_ANALYSISALGORITHMNODE']._serialized_end=166
  _globals['_ANALYSISCREATEREQUEST']._serialized_start=168
  _globals['_ANALYSISCREATEREQUEST']._serialized_end=221
  _globals['_ANALYSISCREATERESPONSE']._serialized_start=223
  _globals['_ANALYSISCREATERESPONSE']._serialized_end=305
  _globals['_ANALYSISALGORITHMCONFIGNODE']._serialized_start=307
  _globals['_ANALYSISALGORITHMCONFIGNODE']._serialized_end=379
  _globals['_ANALYSISGETREQUEST']._serialized_start=381
  _globals['_ANALYSISGETREQUEST']._serialized_end=455
  _globals['_ANALYSIS']._serialized_start=457
  _globals['_ANALYSIS']._serialized_end=557
  _globals['_ANALYSISGETRESPONSE']._serialized_start=559
  _globals['_ANALYSISGETRESPONSE']._serialized_end=679
  _globals['_ANALYSISLISTREQUEST']._serialized_start=682
  _globals['_ANALYSISLISTREQUEST']._serialized_end=869
  _globals['_ANALYSISLISTRESPONSE']._serialized_start=871
  _globals['_ANALYSISLISTRESPONSE']._serialized_end=992
  _globals['_ANALYSISAPI']._serialized_start=995
  _globals['_ANALYSISAPI']._serialized_end=1218
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import struct_pb2 as _struct_pb2
import common_models_pb2 as _common_models_pb2
import aoi_pb2 as _aoi_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from aoi_pb2 import AOITransaction as AOITransaction
from aoi_pb2 import AOIIdentifier as AOIIdentifier
from aoi_pb2 import AOIObject as AOIObject
from aoi_pb2 import AOIVersion as AOIVersion
from aoi_pb2 import AOIInput as AOIInput
from aoi_pb2 import AOICreateRequest as AOICreateRequest
from aoi_pb2 import AOICreateResponse as AOICreateResponse
from aoi_pb2 import AOIUploadRequest as AOIUploadRequest
from aoi_pb2 import AOIUploadResponse as AOIUploadResponse
from aoi_pb2 import AOIGetRequest as AOIGetRequest
from aoi_pb2 import AOIGetResponse as AOIGetResponse
from aoi_pb2 import AOIUpdateRequest as AOIUpdateRequest
from aoi_pb2 import AOIUpdateResponse as AOIUpdateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class ImagerySearchRequest(_message.Message):
    __slots__ = ("aoi_id", "geometry_wkb", "toi_id", "time_range", "data_source_id", "product_spec_name", "data_source_filters", "pagination", "sampling_config")
    class SamplingConfig(_message.Message):
        __slots__ = ("frequency_hours", "tolerance_hours")
        FREQUENCY_HOURS_FIELD_NUMBER: _ClassVar[int]
        TOLERANCE_HOURS_FIELD_NUMBER: _ClassVar[int]
        frequency_hours: int
        tolerance_hours: int
        def __init__(self, frequency_hours: _Optional[int] = ..., tolerance_hours: _Optional[int] = ...) -> None: ...
    class TimeRange(_message.Message):
        __slots__ = ("start_utc", "finish_utc")
        START_UTC_FIELD_NUMBER: _ClassVar[int]
        FINISH_UTC_FIELD_NUMBER: _ClassVar[int]
        start_utc: _timestamp_pb2.Timestamp
        finish_utc: _timestamp_pb2.Timestamp
        def __init__(self, start_utc: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., finish_utc: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    GEOMETRY_WKB_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    TIME_RANGE_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_SPEC_NAME_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_FILTERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SAMPLING_CONFIG_FIELD_NUMBER: _ClassVar[int]
    aoi_id: _aoi_pb2.AOIIdentifier
    geometry_wkb: bytes
    toi_id: str
    time_range: ImagerySearchRequest.TimeRange
    data_source_id: str
    product_spec_name: str
    data_source_filters: _struct_pb2.Struct
    pagination: _common_models_pb2_1.Pagination
    sampling_config: ImagerySearchRequest.SamplingConfig
    def __init__(self, aoi_id: _Optional[_Union[_aoi_pb2.AOIIdentifier, _Mapping]] = ..., geometry_wkb: _Optional[bytes] = ..., toi_id: _Optional[str] = ..., time_range: _Optional[_Union[ImagerySearchRequest.TimeRange, _Mapping]] = ..., data_source_id: _Optional[str] = ..., product_spec_name: _Optional[str] = ..., data_source_filters: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., sampling_config: _Optional[_Union[ImagerySearchRequest.SamplingConfig, _Mapping]] = ...) -> None: ...

class ImagerySearchResponse(_message.Message):
    __slots__ = ("status_code", "results", "pagination")
    class ImagerySearchResult(_message.Message):
        __slots__ = ("id", "provider_scene_id", "image_geom_wkb", "acquired_ts", "metadata")
        ID_FIELD_NUMBER: _ClassVar[int]
        PROVIDER_SCENE_ID_FIELD_NUMBER: _ClassVar[int]
        IMAGE_GEOM_WKB_FIELD_NUMBER: _ClassVar[int]
        ACQUIRED_TS_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        id: str
        provider_scene_id: str
        image_geom_wkb: bytes
        acquired_ts: _timestamp_pb2.Timestamp
        metadata: _struct_pb2.Struct
        def __init__(self, id: _Optional[str] = ..., provider_scene_id: _Optional[str] = ..., image_geom_wkb: _Optional[bytes] = ..., acquired_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    results: _containers.RepeatedCompositeFieldContainer[ImagerySearchResponse.ImagerySearchResult]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., results: _Optional[_Iterable[_Union[ImagerySearchResponse.ImagerySearchResult, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: system.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'system.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csystem.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\"\r\n\x0bPingRequest\"#\n\x0cPingResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x1c\n\x1aPingRequestServerStreaming\"A\n\x1bPingResponseServerStreaming\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r2\xc8\x01\n\tSystemApi\x12T\n\x08get_ping\x12\x14.oi.papi.PingRequest\x1a\x15.oi.papi.PingResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/systemapi/get_ping\x12\x65\n\x16get_ping_server_stream\x12#.oi.papi.PingRequestServerStreaming\x1a$.oi.papi.PingResponseServerStreaming0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'system_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSTEMAPI'].methods_by_name['get_ping']._loaded_options = None
  _globals['_SYSTEMAPI'].methods_by_name['get_ping']._serialized_options = b'\202\323\344\223\002\025\022\023/systemapi/get_ping'
  _globals['_PINGREQUEST']._serialized_start=55
  _globals['_PINGREQUEST']._serialized_end=68
  _globals['_PINGRESPONSE']._serialized_start=70
  _globals['_PINGRESPONSE']._serialized_end=105
  _globals['_PINGREQUESTSERVERSTREAMING']._serialized_start=107
  _globals['_PINGREQUESTSERVERSTREAMING']._serialized_end=135
  _globals['_PINGRESPONSESERVERSTREAMING']._serialized_start=137
  _globals['_PINGRESPONSESERVERSTREAMING']._serialized_end=202
  _globals['_SYSTEMAPI']._serialized_start=205
  _globals['_SYSTEMAPI']._serialized_end=405
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import algorithm_version_pb2 as algorithm__version__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in algorithm_version_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AlgorithmVersionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AlgorithmVersionApi/create',
                request_serializer=algorithm__version__pb2.AlgorithmVersionCreateRequest.SerializeToString,
                response_deserializer=algorithm__version__pb2.AlgorithmVersionCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AlgorithmVersionApi/get',
                request_serializer=algorithm__version__pb2.AlgorithmVersionGetRequest.SerializeToString,
                response_deserializer=algorithm__version__pb2.AlgorithmVersionGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.AlgorithmVersionApi/list',
                request_serializer=algorithm__version__pb2.AlgorithmVersionListRequest.SerializeToString,
                response_deserializer=algorithm__version__pb2.AlgorithmVersionListResponse.FromString,
                _registered_method=True)
        self.deprecate = channel.unary_unary(
                '/oi.papi.AlgorithmVersionApi/deprecate',
                request_serializer=algorithm__version__pb2.AlgorithmVersionDeprecateRequest.SerializeToString,
                response_deserializer=algorithm__version__pb2.AlgorithmVersionDeprecateResponse.FromString,
                _registered_method=True)
        self.deactivate = channel.unary_unary(
                '/oi.papi.AlgorithmVersionApi/deactivate',
                request_serializer=algorithm__version__pb2.AlgorithmVersionDeactivateRequest.SerializeToString,
                response_deserializer=algorithm__version__pb2.AlgorithmVersionDeactivateResponse.FromString,
                _registered_method=True)
        self.activate = channel.unary_unary(
                '/oi.papi.AlgorithmVersionApi/activate',
                request_serializer=algorithm__version__pb2.AlgorithmVersionActivateRequest.SerializeToString,
                response_deserializer=algorithm__version__pb2.AlgorithmVersionActivateResponse.FromString,
                _registered_method=True)


class AlgorithmVersionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Given a top level Algorithm, create a new version, which must be semantically greater than the previously created version.
        Once an AlgorithmVersion has been created, it is immutable. Any changes require a new version to be created.
        Any semantically correct version supplied as part of the AlgorithmVersion manifest will be considered value and assigned to this AlgorithmVersion.
        New versions will be required to be semantically greater than this version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the details for a specific AlgorithmVersion. By default it does include the AlgorithmVersion manifest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List all the AlgorithmVersions that the user has access to.
        Search text will be applied to the entire manifest returning all AlgorithmVersions whose manifest contains the search text.
        Tags will be matched exactly with the tags on the manifest. By default, this method only returns the semantically latest version of each Algorithm that has not been deprecated.
        It does not include manifests in the response.
        If include_all_versions is set to true, all prior versions of an Algorithm including deprecated AlgorithmVersion will be returned, as well.
        If include_manifest is set to true, the corresponding manifest of each algorithm_version will also be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deprecate(self, request, context):
        """
        Deprecate the specific version of this Algorithm.
        Deprecated AlgorithmVersions can still be searched for, metadata can be retrieved, and can still be used to create new AlgorithmConfigs which can be used as part of AlgorithmComputations, but they are no longer actively supported. All AlgorithmConfigs created from this AlgorithmVersion are also deprecated, but can still be used in new AlgorithmComputations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deactivate(self, request, context):
        """
        Deactivate the specific version of this Algorithm. Metadata for deactivated AlgorithmVersions can still be retrieved directly, but they will no longer show up in search results from the list endpoint.
        Deactivated AlgorithmVersions cannot be used to create new AlgorithmConfigs.
        All AlgorithmConfigs created from this AlgorithmVersion are also deactivated and can no longer be used to create new AlgorithmComputations.
        Existing AlgorithmComputations that are already using AlgorithmConfigs created from this AlgorithmVersion will still continue to run.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def activate(self, request, context):
        """
        Activates the specific version of the Algorithm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlgorithmVersionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=algorithm__version__pb2.AlgorithmVersionCreateRequest.FromString,
                    response_serializer=algorithm__version__pb2.AlgorithmVersionCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=algorithm__version__pb2.AlgorithmVersionGetRequest.FromString,
                    response_serializer=algorithm__version__pb2.AlgorithmVersionGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=algorithm__version__pb2.AlgorithmVersionListRequest.FromString,
                    response_serializer=algorithm__version__pb2.AlgorithmVersionListResponse.SerializeToString,
            ),
            'deprecate': grpc.unary_unary_rpc_method_handler(
                    servicer.deprecate,
                    request_deserializer=algorithm__version__pb2.AlgorithmVersionDeprecateRequest.FromString,
                    response_serializer=algorithm__version__pb2.AlgorithmVersionDeprecateResponse.SerializeToString,
            ),
            'deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.deactivate,
                    request_deserializer=algorithm__version__pb2.AlgorithmVersionDeactivateRequest.FromString,
                    response_serializer=algorithm__version__pb2.AlgorithmVersionDeactivateResponse.SerializeToString,
            ),
            'activate': grpc.unary_unary_rpc_method_handler(
                    servicer.activate,
                    request_deserializer=algorithm__version__pb2.AlgorithmVersionActivateRequest.FromString,
                    response_serializer=algorithm__version__pb2.AlgorithmVersionActivateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AlgorithmVersionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AlgorithmVersionApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AlgorithmVersionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmVersionApi/create',
            algorithm__version__pb2.AlgorithmVersionCreateRequest.SerializeToString,
            algorithm__version__pb2.AlgorithmVersionCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmVersionApi/get',
            algorithm__version__pb2.AlgorithmVersionGetRequest.SerializeToString,
            algorithm__version__pb2.AlgorithmVersionGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmVersionApi/list',
            algorithm__version__pb2.AlgorithmVersionListRequest.SerializeToString,
            algorithm__version__pb2.AlgorithmVersionListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def deprecate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmVersionApi/deprecate',
            algorithm__version__pb2.AlgorithmVersionDeprecateRequest.SerializeToString,
            algorithm__version__pb2.AlgorithmVersionDeprecateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmVersionApi/deactivate',
            algorithm__version__pb2.AlgorithmVersionDeactivateRequest.SerializeToString,
            algorithm__version__pb2.AlgorithmVersionDeactivateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmVersionApi/activate',
            algorithm__version__pb2.AlgorithmVersionActivateRequest.SerializeToString,
            algorithm__version__pb2.AlgorithmVersionActivateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_collection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'user_collection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import user_pb2 as user__pb2
try:
  common__models__pb2 = user__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = user__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.user_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15user_collection.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\nuser.proto\"\x94\x01\n\x0eUserCollection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x05users\x18\x03 \x03(\x0b\x32\r.oi.papi.User\"J\n\x0cWellKnownIds\x12\x1b\n\x17USER_COLLECTION_UNKNOWN\x10\x00\x12\x1d\n\x19USER_COLLECTION_ID_PUBLIC\x10\x01\"J\n\x1bUserCollectionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15parent_collection_ids\x18\x02 \x03(\t\"`\n\x1cUserCollectionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\"^\n\x18UserCollectionGetRequest\x12+\n\ncollection\x18\x01 \x01(\x0b\x32\x17.oi.papi.UserCollection\x12\x15\n\rinclude_users\x18\x02 \x01(\x08\"]\n\x19UserCollectionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\"J\n\x1bUserCollectionUpdateRequest\x12+\n\ncollection\x18\x01 \x01(\x0b\x32\x17.oi.papi.UserCollection\"3\n\x1cUserCollectionUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"4\n\x1bUserCollectionDeleteRequest\x12\x15\n\rcollection_id\x18\x01 \x01(\t\"3\n\x1cUserCollectionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"F\n\x1cUserCollectionAddUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x15\n\rcollection_id\x18\x02 \x01(\t\"4\n\x1dUserCollectionAddUserResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"I\n\x1fUserCollectionRemoveUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x15\n\rcollection_id\x18\x02 \x01(\t\"7\n UserCollectionRemoveUserResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xae\x03\n\x19UserCollectionListRequest\x12\x1c\n\x14parent_collection_id\x18\x01 \x01(\t\x12N\n\x0f\x63ollection_type\x18\x02 \x01(\x0e\x32\x35.oi.papi.UserCollectionListRequest.UserCollectionType\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x18\n\x10max_search_depth\x18\x04 \x01(\x05\x12\x15\n\rinclude_users\x18\x05 \x01(\x08\"\xdc\x01\n\x12UserCollectionType\x12 \n\x1cUNKNOWN_USER_COLLECTION_TYPE\x10\x00\x12\x1c\n\x18USER_COLLECTION_TYPE_ANY\x10\x01\x12!\n\x1dUSER_COLLECTION_TYPE_CUSTOMER\x10\x02\x12#\n\x1fUSER_COLLECTION_TYPE_DEPARTMENT\x10\x03\x12\x1d\n\x19USER_COLLECTION_TYPE_USER\x10\x04\x12\x1f\n\x1bUSER_COLLECTION_TYPE_ADMINS\x10\x05\"_\n\x1aUserCollectionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32\x17.oi.papi.UserCollection2\xf6\x04\n\x11UserCollectionApi\x12U\n\x06\x63reate\x12$.oi.papi.UserCollectionCreateRequest\x1a%.oi.papi.UserCollectionCreateResponse\x12L\n\x03get\x12!.oi.papi.UserCollectionGetRequest\x1a\".oi.papi.UserCollectionGetResponse\x12O\n\x04list\x12\".oi.papi.UserCollectionListRequest\x1a#.oi.papi.UserCollectionListResponse\x12U\n\x06update\x12$.oi.papi.UserCollectionUpdateRequest\x1a%.oi.papi.UserCollectionUpdateResponse\x12U\n\x06\x64\x65lete\x12$.oi.papi.UserCollectionDeleteRequest\x1a%.oi.papi.UserCollectionDeleteResponse\x12Y\n\x08\x61\x64\x64_user\x12%.oi.papi.UserCollectionAddUserRequest\x1a&.oi.papi.UserCollectionAddUserResponse\x12\x62\n\x0bremove_user\x12(.oi.papi.UserCollectionRemoveUserRequest\x1a).oi.papi.UserCollectionRemoveUserResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_collection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USERCOLLECTION']._serialized_start=68
  _globals['_USERCOLLECTION']._serialized_end=216
  _globals['_USERCOLLECTION_WELLKNOWNIDS']._serialized_start=142
  _globals['_USERCOLLECTION_WELLKNOWNIDS']._serialized_end=216
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_start=218
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_end=292
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_start=294
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_end=390
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_start=392
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_end=486
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_start=488
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_end=581
  _globals['_USERCOLLECTIONUPDATEREQUEST']._serialized_start=583
  _globals['_USERCOLLECTIONUPDATEREQUEST']._serialized_end=657
  _globals['_USERCOLLECTIONUPDATERESPONSE']._serialized_start=659
  _globals['_USERCOLLECTIONUPDATERESPONSE']._serialized_end=710
  _globals['_USERCOLLECTIONDELETEREQUEST']._serialized_start=712
  _globals['_USERCOLLECTIONDELETEREQUEST']._serialized_end=764
  _globals['_USERCOLLECTIONDELETERESPONSE']._serialized_start=766
  _globals['_USERCOLLECTIONDELETERESPONSE']._serialized_end=817
  _globals['_USERCOLLECTIONADDUSERREQUEST']._serialized_start=819
  _globals['_USERCOLLECTIONADDUSERREQUEST']._serialized_end=889
  _globals['_USERCOLLECTIONADDUSERRESPONSE']._serialized_start=891
  _globals['_USERCOLLECTIONADDUSERRESPONSE']._serialized_end=943
  _globals['_USERCOLLECTIONREMOVEUSERREQUEST']._serialized_start=945
  _globals['_USERCOLLECTIONREMOVEUSERREQUEST']._serialized_end=1018
  _globals['_USERCOLLECTIONREMOVEUSERRESPONSE']._serialized_start=1020
  _globals['_USERCOLLECTIONREMOVEUSERRESPONSE']._serialized_end=1075
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_start=1078
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_end=1508
  _globals['_USERCOLLECTIONLISTREQUEST_USERCOLLECTIONTYPE']._serialized_start=1288
  _globals['_USERCOLLECTIONLISTREQUEST_USERCOLLECTIONTYPE']._serialized_end=1508
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_start=1510
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_end=1605
  _globals['_USERCOLLECTIONAPI']._serialized_start=1608
  _globals['_USERCOLLECTIONAPI']._serialized_end=2238
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import aoi_pb2 as aoi__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in aoi_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AOIApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AOIApi/create',
                request_serializer=aoi__pb2.AOICreateRequest.SerializeToString,
                response_deserializer=aoi__pb2.AOICreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AOIApi/get',
                request_serializer=aoi__pb2.AOIGetRequest.SerializeToString,
                response_deserializer=aoi__pb2.AOIGetResponse.FromString,
                _registered_method=True)
        self.upload = channel.stream_unary(
                '/oi.papi.AOIApi/upload',
                request_serializer=aoi__pb2.AOIUploadRequest.SerializeToString,
                response_deserializer=aoi__pb2.AOIUploadResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.AOIApi/update',
                request_serializer=aoi__pb2.AOIUpdateRequest.SerializeToString,
                response_deserializer=aoi__pb2.AOIUpdateResponse.FromString,
                _registered_method=True)


class AOIApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a new AOI in the system by passing in the required components.
        Pass in an optional aoi_id to act as the parent and create an updated version of the AOI, which will copy fields from the parent unless explicitly overridden by the input parameters.
        The aoi_id and aoi_version of the created AOI are returned. This endpoint is currently limited to 100 AOIs or less.
        If you would like to upload more, refer to aoi.upload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the metadata about the specified AOIs.
        Setting the verbose flag will also include the bytes in wkt format describing the geometry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def upload(self, request_iterator, context):
        """
        Upload new AOIs to the system by passing in the raw bytes.
        Acceptable file formats are .zip (i.e. shapefile), geojson, kml, kmz, and wkt.
        The aoi_id and aoi_version of the created AOIs are returned. This call is asynchronous.
        It will return a aoi_transaction_id that can be used to check the state of the upload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update an list of AOIs. Replaces the contents with the newly given constraints.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AOIApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=aoi__pb2.AOICreateRequest.FromString,
                    response_serializer=aoi__pb2.AOICreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=aoi__pb2.AOIGetRequest.FromString,
                    response_serializer=aoi__pb2.AOIGetResponse.SerializeToString,
            ),
            'upload': grpc.stream_unary_rpc_method_handler(
                    servicer.upload,
                    request_deserializer=aoi__pb2.AOIUploadRequest.FromString,
                    response_serializer=aoi__pb2.AOIUploadResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=aoi__pb2.AOIUpdateRequest.FromString,
                    response_serializer=aoi__pb2.AOIUpdateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AOIApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AOIApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AOIApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOIApi/create',
            aoi__pb2.AOICreateRequest.SerializeToString,
            aoi__pb2.AOICreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOIApi/get',
            aoi__pb2.AOIGetRequest.SerializeToString,
            aoi__pb2.AOIGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def upload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/oi.papi.AOIApi/upload',
            aoi__pb2.AOIUploadRequest.SerializeToString,
            aoi__pb2.AOIUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOIApi/update',
            aoi__pb2.AOIUpdateRequest.SerializeToString,
            aoi__pb2.AOIUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import common_models_pb2 as _common_models_pb2
import filter_pb2 as _filter_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from filter_pb2 import FilterCreateRequest as FilterCreateRequest
from filter_pb2 import FilterCreateResponse as FilterCreateResponse
from filter_pb2 import FilterDeleteRequest as FilterDeleteRequest
from filter_pb2 import FilterDeleteResponse as FilterDeleteResponse
from filter_pb2 import FilterMappingCreateRequest as FilterMappingCreateRequest
from filter_pb2 import FilterMappingCreateResponse as FilterMappingCreateResponse
from filter_pb2 import FilterListRequest as FilterListRequest
from filter_pb2 import Filter as Filter
from filter_pb2 import FilterListResponse as FilterListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectFilter(_message.Message):
    __slots__ = ("filter", "analysis_config_id", "node_name", "project_id")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    filter: _filter_pb2.Filter
    analysis_config_id: str
    node_name: str
    project_id: str
    def __init__(self, filter: _Optional[_Union[_filter_pb2.Filter, _Mapping]] = ..., analysis_config_id: _Optional[str] = ..., node_name: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ProjectFilterMappingCreateRequest(_message.Message):
    __slots__ = ("project_filters",)
    PROJECT_FILTERS_FIELD_NUMBER: _ClassVar[int]
    project_filters: _containers.RepeatedCompositeFieldContainer[ProjectFilter]
    def __init__(self, project_filters: _Optional[_Iterable[_Union[ProjectFilter, _Mapping]]] = ...) -> None: ...

class ProjectFilterMappingCreateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectFilterMappingDeleteRequest(_message.Message):
    __slots__ = ("project_filters",)
    PROJECT_FILTERS_FIELD_NUMBER: _ClassVar[int]
    project_filters: _containers.RepeatedCompositeFieldContainer[ProjectFilter]
    def __init__(self, project_filters: _Optional[_Iterable[_Union[ProjectFilter, _Mapping]]] = ...) -> None: ...

class ProjectFilterMappingDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import aoi_transaction_pb2 as aoi__transaction__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in aoi_transaction_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AOITransactionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/oi.papi.AOITransactionApi/get',
                request_serializer=aoi__transaction__pb2.AOITransactionGetRequest.SerializeToString,
                response_deserializer=aoi__transaction__pb2.AOITransactionGetResponse.FromString,
                _registered_method=True)
        self.status = channel.unary_unary(
                '/oi.papi.AOITransactionApi/status',
                request_serializer=aoi__transaction__pb2.AOITransactionStatusRequest.SerializeToString,
                response_deserializer=aoi__transaction__pb2.AOITransactionStatusResponse.FromString,
                _registered_method=True)


class AOITransactionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get(self, request, context):
        """
        For a the aoi.upload endpoint, an aoi_transaction_id is returned to allow tracking of its status.
        Once complete, this endpoint can be used to return the list of AOIVersions that were successfully created as part of this upload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def status(self, request, context):
        """
        Returns the status of an AOITransaction. Once done, the individual AOIVersions can be retrieved with the aoi_transaction.get endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AOITransactionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=aoi__transaction__pb2.AOITransactionGetRequest.FromString,
                    response_serializer=aoi__transaction__pb2.AOITransactionGetResponse.SerializeToString,
            ),
            'status': grpc.unary_unary_rpc_method_handler(
                    servicer.status,
                    request_deserializer=aoi__transaction__pb2.AOITransactionStatusRequest.FromString,
                    response_serializer=aoi__transaction__pb2.AOITransactionStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AOITransactionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AOITransactionApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AOITransactionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOITransactionApi/get',
            aoi__transaction__pb2.AOITransactionGetRequest.SerializeToString,
            aoi__transaction__pb2.AOITransactionGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOITransactionApi/status',
            aoi__transaction__pb2.AOITransactionStatusRequest.SerializeToString,
            aoi__transaction__pb2.AOITransactionStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_collaborator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'project_collaborator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aproject_collaborator.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"\xd5\x01\n\x13ProjectCollaborator\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x36\n\x04role\x18\x02 \x01(\x0e\x32(.oi.papi.ProjectCollaborator.ProjectRole\x12\x13\n\x0b\x63ustomer_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"R\n\x0bProjectRole\x12\x18\n\x14UNKNOWN_PROJECT_ROLE\x10\x00\x12\x0b\n\x07\x43REATOR\x10\x01\x12\x10\n\x0c\x43OLLABORATOR\x10\x02\x12\n\n\x06VIEWER\x10\x03\"3\n\x1dProjectCollaboratorGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"r\n\x1eProjectCollaboratorGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12;\n\x15project_collaborators\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectCollaborator\"s\n ProjectCollaboratorUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12;\n\x15project_collaborators\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectCollaborator\"8\n!ProjectCollaboratorUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n ProjectCollaboratorDeleteRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08user_ids\x18\x02 \x03(\t\"8\n!ProjectCollaboratorDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xb2\x02\n\x16ProjectCollaboratorApi\x12V\n\x03get\x12&.oi.papi.ProjectCollaboratorGetRequest\x1a\'.oi.papi.ProjectCollaboratorGetResponse\x12_\n\x06update\x12).oi.papi.ProjectCollaboratorUpdateRequest\x1a*.oi.papi.ProjectCollaboratorUpdateResponse\x12_\n\x06\x64\x65lete\x12).oi.papi.ProjectCollaboratorDeleteRequest\x1a*.oi.papi.ProjectCollaboratorDeleteResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_collaborator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTCOLLABORATOR']._serialized_start=61
  _globals['_PROJECTCOLLABORATOR']._serialized_end=274
  _globals['_PROJECTCOLLABORATOR_PROJECTROLE']._serialized_start=192
  _globals['_PROJECTCOLLABORATOR_PROJECTROLE']._serialized_end=274
  _globals['_PROJECTCOLLABORATORGETREQUEST']._serialized_start=276
  _globals['_PROJECTCOLLABORATORGETREQUEST']._serialized_end=327
  _globals['_PROJECTCOLLABORATORGETRESPONSE']._serialized_start=329
  _globals['_PROJECTCOLLABORATORGETRESPONSE']._serialized_end=443
  _globals['_PROJECTCOLLABORATORUPDATEREQUEST']._serialized_start=445
  _globals['_PROJECTCOLLABORATORUPDATEREQUEST']._serialized_end=560
  _globals['_PROJECTCOLLABORATORUPDATERESPONSE']._serialized_start=562
  _globals['_PROJECTCOLLABORATORUPDATERESPONSE']._serialized_end=618
  _globals['_PROJECTCOLLABORATORDELETEREQUEST']._serialized_start=620
  _globals['_PROJECTCOLLABORATORDELETEREQUEST']._serialized_end=692
  _globals['_PROJECTCOLLABORATORDELETERESPONSE']._serialized_start=694
  _globals['_PROJECTCOLLABORATORDELETERESPONSE']._serialized_end=750
  _globals['_PROJECTCOLLABORATORAPI']._serialized_start=753
  _globals['_PROJECTCOLLABORATORAPI']._serialized_end=1059
# @@protoc_insertion_point(module_scope)
